

#if defined(BUILD_DLL) && defined(WIN32)
	#define DLL_ACTION 	__declspec(dllexport)
	#define STDCALL     __stdcall
#elif defined(WIN32)
	#define DLL_ACTION  __declspec(dllimport)
	#define STDCALL     __stdcall	
#else
	#define DLL_ACTION
	#define STDCALL 
#endif


//
// definizione e dimensioni dei buffer:
// smallest_string = lunghezza 32 bytes
// small_string = lunghezza 64 bytes               
// medium_string = lunghezza 128 bytes
// large_string = lunghezza 256 bytes
// largest_string = lunghezza 512 bytes



extern "C" {
	/*
		Funzione: generic_set_remote_host
		-----------------------------------------------------------------------------
		Descrizione: setta il server remoto a cui connettersi per la richiesta.
		Parametri:	 un parametro di tipo stringa di dimensione 32 bytes (smallest)
					 remoteIP: server remoto (pu essere sia nome dominio che IP senza
                     specificare il protocollo - es: www.miosito.it)
		Restituisce: valore boolean
        			 true: settaggio avvenuto
                     false: altrimenti
        Nota:		 usando la famiglia di funzioni vodafone_XXXX_XXXX, le impostazioni
        			 vengono perse.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL generic_set_remote_host(char *remoteIP);


	/*
		Funzione: generic_set_remote_host
		-----------------------------------------------------------------------------
		Descrizione: setta il server remoto a cui connettersi per la richiesta.
		Parametri:	 un parametro di tipo unsigned long
					 remotePort: porta da utilizzare per la connessione
		Restituisce: valore boolean
        			 true: settaggio avvenuto
                     false: altrimenti
        Nota:		 usando la famiglia di funzioni vodafone_XXXX_XXXX, le impostazioni
        			 vengono perse.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL generic_set_remote_port(unsigned long remotePort);


	/*
		Funzione: generic_send_request
		-----------------------------------------------------------------------------
		Descrizione: permette di inviare richieste generiche, ma garantito solo
        			 protocollo HTTP.
		Parametri:	 due parametri di tipo stringa (puntatori a char)
		             due tipo boolean
					 uri: richiesta con relativi parametri
                     (es: '/mio/path/prova.asp?user=a&passwd=b')
                     path: percorso in cui memorizzare la risposta del server senza
                           header. Se impostato a NULL, non salva la risposta
                     isVodafone: specifica se le richieste da inoltrare sono verso Vodafone
		Restituisce: valore tipo boolean
                     true se la richiesta  stata mandata e/o salvata
                     false altrimenti
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL generic_send_request(char *uri, char *path, bool isVodafone, bool isGETMethod);
	

	/*
		Funzione: generic_send_request_mem
		-----------------------------------------------------------------------------
		Descrizione: permette di inviare richieste generiche, ma garantito solo
        			 protocollo HTTP. Per la descrizione guardare la 
        			 generic_send_request().
        			 L'unica differenza  data dalla possibilit di salvare il
        			 contenuto della richiesta direttamente in un'area di memoria
        			 rappresentata da retBuffer. Quest ultimo non pu essere
        			 un valore NULL.
		Restituisce: valore tipo boolean
                     true se la richiesta  stata mandata e/o salvata
                     false altrimenti
        NOTA:         cura del programmatore riservare una quantit di memoria
                     sufficientemente grande da contenere i dati restituiti.
        NOTA per VB: il limite massimo consentito in Visual Basic  pari a
                     65525 bytes. Da usare sempre come stringa fissa.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL generic_send_request_mem(char *uri, char *retBuffer, bool isVodafone, bool isGETMethod);

	
	/*
		Funzione: generic_get_server_name
		-----------------------------------------------------------------------------
		Descrizione: restituisce la signature del server web che ha risposto
		Parametri:	 un parametro di tipo stringa (puntatore a char)					 
		Restituisce: valore lungo senza segno
        			 restituisce il numero di caratteri che sono stati letti
                     altrimenti zero
        Nota:		 oltre a restituire zero in caso di non successo, imposta
                     anche il buffer retServerName a vuoto.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION unsigned long STDCALL generic_get_server_name(char *retServerName);		
	
	
	/*
		Funzione: generic_get_cookie
		-----------------------------------------------------------------------------
		Descrizione: restituisce i cookie settati dalla risposta del server.
		Parametri:	 un parametro di tipo stringa (puntatore a char) di largest_string					 
		             retCookie: conterr i cookie settati
		             un parametro di tipo boolean
		             isVodafone: se la richiesta  specifica per vodafone
		Restituisce: valore lungo senza segno
        			 restituisce il numero di caratteri che sono stati letti
                     altrimenti zero
        Nota:		 oltre a restituire zero in caso di non successo, imposta
                     anche il buffer retCookie a vuoto.
        ATTENZIONE:  la funzione potrebbe causare un buffer overflow in caso di
                     eccedenza di informazioni.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION unsigned long STDCALL generic_get_cookie(char *retCookie, bool isVodafone);
	
	
	/*
		Funzione: generic_reset_cookie
		-----------------------------------------------------------------------------
		Descrizione: quando vengono effettuate delle richieste generiche, i cookie
                     vengono memorizzati ed accumulati in memoria. Talvolta si 
                     desidera effettuare delle richieste ex-novo (es: verso altri
                     host) per cui  necessario pulire i cookie precedentemente
                     usati.
                     La funzione permette di effettuare questa operazione.
		Parametri:	 nessuno
		Restituisce: nessuno
		NOTA:        da chiamare prima di inviare una nuova richiesta
		             tramite la funzione generic_send_request().
		------------------------------------------------------------------------------
	*/	
    DLL_ACTION void STDCALL generic_reset_cookie(void);
    
};

 
